# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.containerregistry.v1 import lifecycle_policy_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2
from yandex.cloud.containerregistry.v1 import lifecycle_policy_service_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class LifecyclePolicyServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/Get',
        request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.GetLifecyclePolicyRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2.LifecyclePolicy.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/List',
        request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListLifecyclePoliciesRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListLifecyclePoliciesResponse.FromString,
        )
    self.Create = channel.unary_unary(
        '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/Create',
        request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.CreateLifecyclePolicyRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/Update',
        request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.UpdateLifecyclePolicyRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/Delete',
        request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.DeleteLifecyclePolicyRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.DryRun = channel.unary_unary(
        '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/DryRun',
        request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.DryRunLifecyclePolicyRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.GetDryRunResult = channel.unary_unary(
        '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/GetDryRunResult',
        request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.GetDryRunLifecyclePolicyResultRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.DryRunLifecyclePolicyResult.FromString,
        )
    self.ListDryRunResults = channel.unary_unary(
        '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/ListDryRunResults',
        request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultsResponse.FromString,
        )
    self.ListDryRunResultAffectedImages = channel.unary_unary(
        '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/ListDryRunResultAffectedImages',
        request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultAffectedImagesRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultAffectedImagesResponse.FromString,
        )


class LifecyclePolicyServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DryRun(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetDryRunResult(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListDryRunResults(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListDryRunResultAffectedImages(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_LifecyclePolicyServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.GetLifecyclePolicyRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2.LifecyclePolicy.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListLifecyclePoliciesRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListLifecyclePoliciesResponse.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.CreateLifecyclePolicyRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.UpdateLifecyclePolicyRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.DeleteLifecyclePolicyRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'DryRun': grpc.unary_unary_rpc_method_handler(
          servicer.DryRun,
          request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.DryRunLifecyclePolicyRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'GetDryRunResult': grpc.unary_unary_rpc_method_handler(
          servicer.GetDryRunResult,
          request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.GetDryRunLifecyclePolicyResultRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.DryRunLifecyclePolicyResult.SerializeToString,
      ),
      'ListDryRunResults': grpc.unary_unary_rpc_method_handler(
          servicer.ListDryRunResults,
          request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultsResponse.SerializeToString,
      ),
      'ListDryRunResultAffectedImages': grpc.unary_unary_rpc_method_handler(
          servicer.ListDryRunResultAffectedImages,
          request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultAffectedImagesRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultAffectedImagesResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.containerregistry.v1.LifecyclePolicyService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.ai.translate.v2 import translation_service_pb2 as yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2


class TranslationServiceStub(object):
  """A set of methods for the Yandex Translate service.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Translate = channel.unary_unary(
        '/yandex.cloud.ai.translate.v2.TranslationService/Translate',
        request_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.TranslateRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.TranslateResponse.FromString,
        )
    self.DetectLanguage = channel.unary_unary(
        '/yandex.cloud.ai.translate.v2.TranslationService/DetectLanguage',
        request_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.DetectLanguageRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.DetectLanguageResponse.FromString,
        )
    self.ListLanguages = channel.unary_unary(
        '/yandex.cloud.ai.translate.v2.TranslationService/ListLanguages',
        request_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.ListLanguagesRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.ListLanguagesResponse.FromString,
        )


class TranslationServiceServicer(object):
  """A set of methods for the Yandex Translate service.
  """

  def Translate(self, request, context):
    """Translates the text to the specified language.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DetectLanguage(self, request, context):
    """Detects the language of the text.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListLanguages(self, request, context):
    """Retrieves the list of supported languages.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_TranslationServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Translate': grpc.unary_unary_rpc_method_handler(
          servicer.Translate,
          request_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.TranslateRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.TranslateResponse.SerializeToString,
      ),
      'DetectLanguage': grpc.unary_unary_rpc_method_handler(
          servicer.DetectLanguage,
          request_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.DetectLanguageRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.DetectLanguageResponse.SerializeToString,
      ),
      'ListLanguages': grpc.unary_unary_rpc_method_handler(
          servicer.ListLanguages,
          request_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.ListLanguagesRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.ListLanguagesResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.ai.translate.v2.TranslationService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.mdb.mysql.v1 import cluster_pb2 as yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__pb2
from yandex.cloud.mdb.mysql.v1 import cluster_service_pb2 as yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class ClusterServiceStub(object):
  """A set of methods for managing MySQL clusters.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/Get',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.GetClusterRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__pb2.Cluster.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/List',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClustersRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClustersResponse.FromString,
        )
    self.Create = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/Create',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.CreateClusterRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/Update',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.UpdateClusterRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/Delete',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.DeleteClusterRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Start = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/Start',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.StartClusterRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Stop = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/Stop',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.StopClusterRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Move = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/Move',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.MoveClusterRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Backup = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/Backup',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.BackupClusterRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Restore = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/Restore',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.RestoreClusterRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.StartFailover = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/StartFailover',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.StartClusterFailoverRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListLogs = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/ListLogs',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClusterLogsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClusterLogsResponse.FromString,
        )
    self.StreamLogs = channel.unary_stream(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/StreamLogs',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.StreamClusterLogsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.LogRecord.FromString,
        )
    self.ListOperations = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/ListOperations',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClusterOperationsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClusterOperationsResponse.FromString,
        )
    self.ListBackups = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/ListBackups',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClusterBackupsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClusterBackupsResponse.FromString,
        )
    self.ListHosts = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/ListHosts',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClusterHostsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClusterHostsResponse.FromString,
        )
    self.AddHosts = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/AddHosts',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.AddClusterHostsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.DeleteHosts = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.ClusterService/DeleteHosts',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.DeleteClusterHostsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )


class ClusterServiceServicer(object):
  """A set of methods for managing MySQL clusters.
  """

  def Get(self, request, context):
    """Returns the specified MySQL cluster.

    To get the list of available MySQL clusters, make a [List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """Retrieves the list of MySQL clusters that belong to the specified folder.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    """Creates a MySQL cluster in the specified folder.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Modifies the specified MySQL cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Deletes the specified MySQL cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Start(self, request, context):
    """Starts the specified MySQL cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Stop(self, request, context):
    """Stops the specified MySQL cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Move(self, request, context):
    """Moves the specified MySQL cluster to the specified folder.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Backup(self, request, context):
    """Creates a backup for the specified MySQL cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Restore(self, request, context):
    """Creates a new MySQL cluster using the specified backup.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StartFailover(self, request, context):
    """Start a manual failover on the specified MySQL cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListLogs(self, request, context):
    """Retrieves logs for the specified MySQL cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StreamLogs(self, request, context):
    """Same as ListLogs but using server-side streaming. Also allows for 'tail -f' semantics.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListOperations(self, request, context):
    """Retrieves the list of operations for the specified MySQL cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListBackups(self, request, context):
    """Retrieves the list of available backups for the specified MySQL cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListHosts(self, request, context):
    """Retrieves a list of hosts for the specified MySQL cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddHosts(self, request, context):
    """Creates new hosts for a cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteHosts(self, request, context):
    """Deletes the specified hosts for a cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ClusterServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.GetClusterRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__pb2.Cluster.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClustersRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClustersResponse.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.CreateClusterRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.UpdateClusterRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.DeleteClusterRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Start': grpc.unary_unary_rpc_method_handler(
          servicer.Start,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.StartClusterRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Stop': grpc.unary_unary_rpc_method_handler(
          servicer.Stop,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.StopClusterRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Move': grpc.unary_unary_rpc_method_handler(
          servicer.Move,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.MoveClusterRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Backup': grpc.unary_unary_rpc_method_handler(
          servicer.Backup,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.BackupClusterRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Restore': grpc.unary_unary_rpc_method_handler(
          servicer.Restore,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.RestoreClusterRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'StartFailover': grpc.unary_unary_rpc_method_handler(
          servicer.StartFailover,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.StartClusterFailoverRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListLogs': grpc.unary_unary_rpc_method_handler(
          servicer.ListLogs,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClusterLogsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClusterLogsResponse.SerializeToString,
      ),
      'StreamLogs': grpc.unary_stream_rpc_method_handler(
          servicer.StreamLogs,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.StreamClusterLogsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.LogRecord.SerializeToString,
      ),
      'ListOperations': grpc.unary_unary_rpc_method_handler(
          servicer.ListOperations,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClusterOperationsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClusterOperationsResponse.SerializeToString,
      ),
      'ListBackups': grpc.unary_unary_rpc_method_handler(
          servicer.ListBackups,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClusterBackupsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClusterBackupsResponse.SerializeToString,
      ),
      'ListHosts': grpc.unary_unary_rpc_method_handler(
          servicer.ListHosts,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClusterHostsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.ListClusterHostsResponse.SerializeToString,
      ),
      'AddHosts': grpc.unary_unary_rpc_method_handler(
          servicer.AddHosts,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.AddClusterHostsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'DeleteHosts': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteHosts,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_cluster__service__pb2.DeleteClusterHostsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.mdb.mysql.v1.ClusterService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.vpc.v1 import subnet_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__pb2
from yandex.cloud.vpc.v1 import subnet_service_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2


class SubnetServiceStub(object):
  """A set of methods for managing Subnet resources.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.vpc.v1.SubnetService/Get',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.GetSubnetRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__pb2.Subnet.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.vpc.v1.SubnetService/List',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.ListSubnetsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.ListSubnetsResponse.FromString,
        )
    self.Create = channel.unary_unary(
        '/yandex.cloud.vpc.v1.SubnetService/Create',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.CreateSubnetRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.vpc.v1.SubnetService/Update',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.UpdateSubnetRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.vpc.v1.SubnetService/Delete',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.DeleteSubnetRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListOperations = channel.unary_unary(
        '/yandex.cloud.vpc.v1.SubnetService/ListOperations',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.ListSubnetOperationsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.ListSubnetOperationsResponse.FromString,
        )
    self.Move = channel.unary_unary(
        '/yandex.cloud.vpc.v1.SubnetService/Move',
        request_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.MoveSubnetRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )


class SubnetServiceServicer(object):
  """A set of methods for managing Subnet resources.
  """

  def Get(self, request, context):
    """Returns the specified Subnet resource.

    To get the list of available Subnet resources, make a [List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """Retrieves the list of Subnet resources in the specified folder.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    """Creates a subnet in the specified folder and network.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Updates the specified subnet.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Deletes the specified subnet.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListOperations(self, request, context):
    """List operations for the specified subnet.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Move(self, request, context):
    """Move subnet to another folder.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SubnetServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.GetSubnetRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__pb2.Subnet.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.ListSubnetsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.ListSubnetsResponse.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.CreateSubnetRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.UpdateSubnetRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.DeleteSubnetRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListOperations': grpc.unary_unary_rpc_method_handler(
          servicer.ListOperations,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.ListSubnetOperationsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.ListSubnetOperationsResponse.SerializeToString,
      ),
      'Move': grpc.unary_unary_rpc_method_handler(
          servicer.Move,
          request_deserializer=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__service__pb2.MoveSubnetRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.vpc.v1.SubnetService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.loadbalancer.v1 import network_load_balancer_pb2 as yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__pb2
from yandex.cloud.loadbalancer.v1 import network_load_balancer_service_pb2 as yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class NetworkLoadBalancerServiceStub(object):
  """A set of methods for managing NetworkLoadBalancer resources.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Get',
        request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.GetNetworkLoadBalancerRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__pb2.NetworkLoadBalancer.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/List',
        request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancersRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancersResponse.FromString,
        )
    self.Create = channel.unary_unary(
        '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Create',
        request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.CreateNetworkLoadBalancerRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Update',
        request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.UpdateNetworkLoadBalancerRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Delete',
        request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.DeleteNetworkLoadBalancerRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Start = channel.unary_unary(
        '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Start',
        request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.StartNetworkLoadBalancerRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Stop = channel.unary_unary(
        '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Stop',
        request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.StopNetworkLoadBalancerRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.AttachTargetGroup = channel.unary_unary(
        '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/AttachTargetGroup',
        request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.AttachNetworkLoadBalancerTargetGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.DetachTargetGroup = channel.unary_unary(
        '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/DetachTargetGroup',
        request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.DetachNetworkLoadBalancerTargetGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.GetTargetStates = channel.unary_unary(
        '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/GetTargetStates',
        request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.GetTargetStatesRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.GetTargetStatesResponse.FromString,
        )
    self.AddListener = channel.unary_unary(
        '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/AddListener',
        request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.AddNetworkLoadBalancerListenerRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.RemoveListener = channel.unary_unary(
        '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/RemoveListener',
        request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.RemoveNetworkLoadBalancerListenerRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListOperations = channel.unary_unary(
        '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/ListOperations',
        request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancerOperationsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancerOperationsResponse.FromString,
        )


class NetworkLoadBalancerServiceServicer(object):
  """A set of methods for managing NetworkLoadBalancer resources.
  """

  def Get(self, request, context):
    """Returns the specified NetworkLoadBalancer resource.

    Get the list of available NetworkLoadBalancer resources by making a [List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """Retrieves the list of NetworkLoadBalancer resources in the specified folder.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    """Creates a network load balancer in the specified folder using the data specified in the request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Updates the specified network load balancer.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Deletes the specified network load balancer.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Start(self, request, context):
    """Starts load balancing and health checking with the specified network load balancer with specified settings.
    Changes network load balancer status to `` ACTIVE ``.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Stop(self, request, context):
    """Stops load balancing and health checking with the specified network load balancer.
    Changes load balancer status to `` STOPPED ``.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AttachTargetGroup(self, request, context):
    """Attaches a target group to the specified network load balancer.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DetachTargetGroup(self, request, context):
    """Detaches the target group from the specified network load balancer.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetTargetStates(self, request, context):
    """Gets states of target resources in the attached target group.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddListener(self, request, context):
    """Adds a listener to the specified network load balancer.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RemoveListener(self, request, context):
    """Removes the listener from the specified network load balancer.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListOperations(self, request, context):
    """Lists operations for the specified network load balancer.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_NetworkLoadBalancerServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.GetNetworkLoadBalancerRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__pb2.NetworkLoadBalancer.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancersRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancersResponse.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.CreateNetworkLoadBalancerRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.UpdateNetworkLoadBalancerRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.DeleteNetworkLoadBalancerRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Start': grpc.unary_unary_rpc_method_handler(
          servicer.Start,
          request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.StartNetworkLoadBalancerRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Stop': grpc.unary_unary_rpc_method_handler(
          servicer.Stop,
          request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.StopNetworkLoadBalancerRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'AttachTargetGroup': grpc.unary_unary_rpc_method_handler(
          servicer.AttachTargetGroup,
          request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.AttachNetworkLoadBalancerTargetGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'DetachTargetGroup': grpc.unary_unary_rpc_method_handler(
          servicer.DetachTargetGroup,
          request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.DetachNetworkLoadBalancerTargetGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'GetTargetStates': grpc.unary_unary_rpc_method_handler(
          servicer.GetTargetStates,
          request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.GetTargetStatesRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.GetTargetStatesResponse.SerializeToString,
      ),
      'AddListener': grpc.unary_unary_rpc_method_handler(
          servicer.AddListener,
          request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.AddNetworkLoadBalancerListenerRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'RemoveListener': grpc.unary_unary_rpc_method_handler(
          servicer.RemoveListener,
          request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.RemoveNetworkLoadBalancerListenerRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListOperations': grpc.unary_unary_rpc_method_handler(
          servicer.ListOperations,
          request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancerOperationsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancerOperationsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.k8s.v1 import version_service_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_version__service__pb2


class VersionServiceStub(object):
  """A set of methods for managing Kubernetes versions.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.List = channel.unary_unary(
        '/yandex.cloud.k8s.v1.VersionService/List',
        request_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_version__service__pb2.ListVersionsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_version__service__pb2.ListVersionsResponse.FromString,
        )


class VersionServiceServicer(object):
  """A set of methods for managing Kubernetes versions.
  """

  def List(self, request, context):
    """Retrieves the list of versions in the specified release channel.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_VersionServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_version__service__pb2.ListVersionsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_version__service__pb2.ListVersionsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.k8s.v1.VersionService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.iot.devices.v1 import device_data_service_pb2 as yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__data__service__pb2


class DeviceDataServiceStub(object):
  """A set of methods to work with IoT Core messages on behalf of device
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Publish = channel.unary_unary(
        '/yandex.cloud.iot.devices.v1.DeviceDataService/Publish',
        request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__data__service__pb2.PublishDeviceDataRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__data__service__pb2.PublishDeviceDataResponse.FromString,
        )


class DeviceDataServiceServicer(object):
  """A set of methods to work with IoT Core messages on behalf of device
  """

  def Publish(self, request, context):
    """Publishes message on behalf of specified device
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DeviceDataServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Publish': grpc.unary_unary_rpc_method_handler(
          servicer.Publish,
          request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__data__service__pb2.PublishDeviceDataRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__data__service__pb2.PublishDeviceDataResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.iot.devices.v1.DeviceDataService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.iam.v1 import api_key_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__pb2
from yandex.cloud.iam.v1 import api_key_service_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class ApiKeyServiceStub(object):
  """A set of methods for managing API keys.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.List = channel.unary_unary(
        '/yandex.cloud.iam.v1.ApiKeyService/List',
        request_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.ListApiKeysRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.ListApiKeysResponse.FromString,
        )
    self.Get = channel.unary_unary(
        '/yandex.cloud.iam.v1.ApiKeyService/Get',
        request_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.GetApiKeyRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__pb2.ApiKey.FromString,
        )
    self.Create = channel.unary_unary(
        '/yandex.cloud.iam.v1.ApiKeyService/Create',
        request_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.CreateApiKeyRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.CreateApiKeyResponse.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.iam.v1.ApiKeyService/Update',
        request_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.UpdateApiKeyRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.iam.v1.ApiKeyService/Delete',
        request_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.DeleteApiKeyRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListOperations = channel.unary_unary(
        '/yandex.cloud.iam.v1.ApiKeyService/ListOperations',
        request_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.ListApiKeyOperationsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.ListApiKeyOperationsResponse.FromString,
        )


class ApiKeyServiceServicer(object):
  """A set of methods for managing API keys.
  """

  def List(self, request, context):
    """Retrieves the list of API keys for the specified service account.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Get(self, request, context):
    """Returns the specified API key.

    To get the list of available API keys, make a [List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    """Creates an API key for the specified service account.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Updates the specified API key.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Deletes the specified API key.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListOperations(self, request, context):
    """Retrieves the list of operations for the specified API key.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ApiKeyServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.ListApiKeysRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.ListApiKeysResponse.SerializeToString,
      ),
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.GetApiKeyRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__pb2.ApiKey.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.CreateApiKeyRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.CreateApiKeyResponse.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.UpdateApiKeyRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.DeleteApiKeyRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListOperations': grpc.unary_unary_rpc_method_handler(
          servicer.ListOperations,
          request_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.ListApiKeyOperationsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__service__pb2.ListApiKeyOperationsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.iam.v1.ApiKeyService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.resourcemanager.v1 import cloud_pb2 as yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__pb2
from yandex.cloud.resourcemanager.v1 import cloud_service_pb2 as yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__service__pb2


class CloudServiceStub(object):
  """A set of methods for managing Cloud resources.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.resourcemanager.v1.CloudService/Get',
        request_serializer=yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__service__pb2.GetCloudRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__pb2.Cloud.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.resourcemanager.v1.CloudService/List',
        request_serializer=yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__service__pb2.ListCloudsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__service__pb2.ListCloudsResponse.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.resourcemanager.v1.CloudService/Update',
        request_serializer=yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__service__pb2.UpdateCloudRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListOperations = channel.unary_unary(
        '/yandex.cloud.resourcemanager.v1.CloudService/ListOperations',
        request_serializer=yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__service__pb2.ListCloudOperationsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__service__pb2.ListCloudOperationsResponse.FromString,
        )
    self.ListAccessBindings = channel.unary_unary(
        '/yandex.cloud.resourcemanager.v1.CloudService/ListAccessBindings',
        request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
        )
    self.SetAccessBindings = channel.unary_unary(
        '/yandex.cloud.resourcemanager.v1.CloudService/SetAccessBindings',
        request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.UpdateAccessBindings = channel.unary_unary(
        '/yandex.cloud.resourcemanager.v1.CloudService/UpdateAccessBindings',
        request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )


class CloudServiceServicer(object):
  """A set of methods for managing Cloud resources.
  """

  def Get(self, request, context):
    """Returns the specified Cloud resource.

    To get the list of available Cloud resources, make a [List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """Retrieves the list of Cloud resources.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Updates the specified cloud.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListOperations(self, request, context):
    """Lists operations for the specified cloud.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListAccessBindings(self, request, context):
    """access

    Lists access bindings for the specified cloud.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetAccessBindings(self, request, context):
    """Sets access bindings for the specified cloud.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateAccessBindings(self, request, context):
    """Updates access bindings for the specified cloud.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CloudServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__service__pb2.GetCloudRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__pb2.Cloud.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__service__pb2.ListCloudsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__service__pb2.ListCloudsResponse.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__service__pb2.UpdateCloudRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListOperations': grpc.unary_unary_rpc_method_handler(
          servicer.ListOperations,
          request_deserializer=yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__service__pb2.ListCloudOperationsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__service__pb2.ListCloudOperationsResponse.SerializeToString,
      ),
      'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
          servicer.ListAccessBindings,
          request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
      ),
      'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
          servicer.SetAccessBindings,
          request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateAccessBindings,
          request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.resourcemanager.v1.CloudService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.operation import operation_service_pb2 as yandex_dot_cloud_dot_operation_dot_operation__service__pb2


class OperationServiceStub(object):
  """A set of methods for managing operations for asynchronous API requests.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.operation.OperationService/Get',
        request_serializer=yandex_dot_cloud_dot_operation_dot_operation__service__pb2.GetOperationRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Cancel = channel.unary_unary(
        '/yandex.cloud.operation.OperationService/Cancel',
        request_serializer=yandex_dot_cloud_dot_operation_dot_operation__service__pb2.CancelOperationRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )


class OperationServiceServicer(object):
  """A set of methods for managing operations for asynchronous API requests.
  """

  def Get(self, request, context):
    """Returns the specified Operation resource.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Cancel(self, request, context):
    """Cancels the specified operation.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_OperationServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_operation_dot_operation__service__pb2.GetOperationRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Cancel': grpc.unary_unary_rpc_method_handler(
          servicer.Cancel,
          request_deserializer=yandex_dot_cloud_dot_operation_dot_operation__service__pb2.CancelOperationRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.operation.OperationService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.endpoint import api_endpoint_pb2 as yandex_dot_cloud_dot_endpoint_dot_api__endpoint__pb2
from yandex.cloud.endpoint import api_endpoint_service_pb2 as yandex_dot_cloud_dot_endpoint_dot_api__endpoint__service__pb2


class ApiEndpointServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.endpoint.ApiEndpointService/Get',
        request_serializer=yandex_dot_cloud_dot_endpoint_dot_api__endpoint__service__pb2.GetApiEndpointRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_endpoint_dot_api__endpoint__pb2.ApiEndpoint.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.endpoint.ApiEndpointService/List',
        request_serializer=yandex_dot_cloud_dot_endpoint_dot_api__endpoint__service__pb2.ListApiEndpointsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_endpoint_dot_api__endpoint__service__pb2.ListApiEndpointsResponse.FromString,
        )


class ApiEndpointServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ApiEndpointServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_endpoint_dot_api__endpoint__service__pb2.GetApiEndpointRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_endpoint_dot_api__endpoint__pb2.ApiEndpoint.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_endpoint_dot_api__endpoint__service__pb2.ListApiEndpointsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_endpoint_dot_api__endpoint__service__pb2.ListApiEndpointsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.endpoint.ApiEndpointService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mysql/v1/config/mysql8_0.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/mysql/v1/config/mysql8_0.proto',
  package='yandex.cloud.mdb.mysql.v1.config',
  syntax='proto3',
  serialized_options=b'\n$yandex.cloud.api.mdb.mysql.v1.configZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1/config;mysql',
  serialized_pb=b'\n/yandex/cloud/mdb/mysql/v1/config/mysql8_0.proto\x12 yandex.cloud.mdb.mysql.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\x96\x10\n\x0eMysqlConfig8_0\x12K\n\x17innodb_buffer_pool_size\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\xfa\xc7\x31\t>=5242880\x12\x42\n\x0fmax_connections\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-10000\x12\x35\n\x0flong_query_time\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12/\n\x0bgeneral_log\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\taudit_log\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12J\n\x08sql_mode\x18\x06 \x03(\x0e\x32\x38.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.SQLMode\x12K\n\x12max_allowed_packet\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x31\x30\x32\x34-134217728\x12\x62\n\x1d\x64\x65\x66\x61ult_authentication_plugin\x18\x08 \x01(\x0e\x32;.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.AuthPlugin\x12L\n\x1einnodb_flush_log_at_trx_commit\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03\x31-2\x12J\n\x18innodb_lock_wait_timeout\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x31-28800\x12\x64\n\x15transaction_isolation\x18\x0b \x01(\x0e\x32\x45.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.TransactionIsolation\x12>\n\x1ainnodb_print_all_deadlocks\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x10net_read_timeout\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1200\x12\x42\n\x11net_write_timeout\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1200\x12I\n\x14group_concat_max_len\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n4-33554432\x12G\n\x0etmp_table_size\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x31\x30\x32\x34-134217728\x12L\n\x13max_heap_table_size\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x31\x30\x32\x34-134217728\x12\x19\n\x11\x64\x65\x66\x61ult_time_zone\x18\x12 \x01(\t\x12\x1c\n\x14\x63haracter_set_server\x18\x13 \x01(\t\x12\x18\n\x10\x63ollation_server\x18\x14 \x01(\t\"\xf2\x03\n\x07SQLMode\x12\x17\n\x13SQLMODE_UNSPECIFIED\x10\x00\x12\x17\n\x13\x41LLOW_INVALID_DATES\x10\x01\x12\x0f\n\x0b\x41NSI_QUOTES\x10\x02\x12\x1e\n\x1a\x45RROR_FOR_DIVISION_BY_ZERO\x10\x03\x12\x17\n\x13HIGH_NOT_PRECEDENCE\x10\x04\x12\x10\n\x0cIGNORE_SPACE\x10\x05\x12\x19\n\x15NO_AUTO_VALUE_ON_ZERO\x10\x06\x12\x18\n\x14NO_BACKSLASH_ESCAPES\x10\x07\x12\x1a\n\x16NO_ENGINE_SUBSTITUTION\x10\x08\x12\x1b\n\x17NO_UNSIGNED_SUBTRACTION\x10\t\x12\x10\n\x0cNO_ZERO_DATE\x10\n\x12\x13\n\x0fNO_ZERO_IN_DATE\x10\x0b\x12\x16\n\x12ONLY_FULL_GROUP_BY\x10\x0f\x12\x1b\n\x17PAD_CHAR_TO_FULL_LENGTH\x10\x10\x12\x13\n\x0fPIPES_AS_CONCAT\x10\x11\x12\x11\n\rREAL_AS_FLOAT\x10\x12\x12\x15\n\x11STRICT_ALL_TABLES\x10\x13\x12\x17\n\x13STRICT_TRANS_TABLES\x10\x14\x12\x1c\n\x18TIME_TRUNCATE_FRACTIONAL\x10\x15\x12\x08\n\x04\x41NSI\x10\x16\x12\x0f\n\x0bTRADITIONAL\x10\x17\"t\n\nAuthPlugin\x12\x1b\n\x17\x41UTH_PLUGIN_UNSPECIFIED\x10\x00\x12\x19\n\x15MYSQL_NATIVE_PASSWORD\x10\x01\x12\x19\n\x15\x43\x41\x43HING_SHA2_PASSWORD\x10\x02\x12\x13\n\x0fSHA256_PASSWORD\x10\x03\"x\n\x14TransactionIsolation\x12%\n!TRANSACTION_ISOLATION_UNSPECIFIED\x10\x00\x12\x12\n\x0eREAD_COMMITTED\x10\x01\x12\x13\n\x0fREPEATABLE_READ\x10\x02\x12\x10\n\x0cSERIALIZABLE\x10\x03\"\xf0\x01\n\x11MysqlConfigSet8_0\x12J\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0\x12\x45\n\x0buser_config\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0\x12H\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0Br\n$yandex.cloud.api.mdb.mysql.v1.configZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1/config;mysqlb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])



_MYSQLCONFIG8_0_SQLMODE = _descriptor.EnumDescriptor(
  name='SQLMode',
  full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.SQLMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SQLMODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALLOW_INVALID_DATES', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANSI_QUOTES', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FOR_DIVISION_BY_ZERO', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HIGH_NOT_PRECEDENCE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IGNORE_SPACE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_AUTO_VALUE_ON_ZERO', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_BACKSLASH_ESCAPES', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_ENGINE_SUBSTITUTION', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_UNSIGNED_SUBTRACTION', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_ZERO_DATE', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_ZERO_IN_DATE', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONLY_FULL_GROUP_BY', index=12, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAD_CHAR_TO_FULL_LENGTH', index=13, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIPES_AS_CONCAT', index=14, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REAL_AS_FLOAT', index=15, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRICT_ALL_TABLES', index=16, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRICT_TRANS_TABLES', index=17, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIME_TRUNCATE_FRACTIONAL', index=18, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANSI', index=19, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRADITIONAL', index=20, number=23,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1481,
  serialized_end=1979,
)
_sym_db.RegisterEnumDescriptor(_MYSQLCONFIG8_0_SQLMODE)

_MYSQLCONFIG8_0_AUTHPLUGIN = _descriptor.EnumDescriptor(
  name='AuthPlugin',
  full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.AuthPlugin',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTH_PLUGIN_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MYSQL_NATIVE_PASSWORD', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CACHING_SHA2_PASSWORD', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHA256_PASSWORD', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1981,
  serialized_end=2097,
)
_sym_db.RegisterEnumDescriptor(_MYSQLCONFIG8_0_AUTHPLUGIN)

_MYSQLCONFIG8_0_TRANSACTIONISOLATION = _descriptor.EnumDescriptor(
  name='TransactionIsolation',
  full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.TransactionIsolation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRANSACTION_ISOLATION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READ_COMMITTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REPEATABLE_READ', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERIALIZABLE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2099,
  serialized_end=2219,
)
_sym_db.RegisterEnumDescriptor(_MYSQLCONFIG8_0_TRANSACTIONISOLATION)


_MYSQLCONFIG8_0 = _descriptor.Descriptor(
  name='MysqlConfig8_0',
  full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='innodb_buffer_pool_size', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.innodb_buffer_pool_size', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\t>=5242880', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_connections', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.max_connections', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\01010-10000', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_query_time', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.long_query_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='general_log', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.general_log', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audit_log', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.audit_log', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sql_mode', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.sql_mode', index=5,
      number=6, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_allowed_packet', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.max_allowed_packet', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0161024-134217728', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_authentication_plugin', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.default_authentication_plugin', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='innodb_flush_log_at_trx_commit', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.innodb_flush_log_at_trx_commit', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0031-2', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='innodb_lock_wait_timeout', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.innodb_lock_wait_timeout', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0071-28800', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_isolation', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.transaction_isolation', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='innodb_print_all_deadlocks', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.innodb_print_all_deadlocks', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='net_read_timeout', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.net_read_timeout', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0061-1200', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='net_write_timeout', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.net_write_timeout', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0061-1200', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_concat_max_len', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.group_concat_max_len', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\n4-33554432', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tmp_table_size', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.tmp_table_size', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0161024-134217728', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_heap_table_size', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.max_heap_table_size', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0161024-134217728', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_time_zone', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.default_time_zone', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='character_set_server', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.character_set_server', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collation_server', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.collation_server', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MYSQLCONFIG8_0_SQLMODE,
    _MYSQLCONFIG8_0_AUTHPLUGIN,
    _MYSQLCONFIG8_0_TRANSACTIONISOLATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=2219,
)


_MYSQLCONFIGSET8_0 = _descriptor.Descriptor(
  name='MysqlConfigSet8_0',
  full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfigSet8_0',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfigSet8_0.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfigSet8_0.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.mysql.v1.config.MysqlConfigSet8_0.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2222,
  serialized_end=2462,
)

_MYSQLCONFIG8_0.fields_by_name['innodb_buffer_pool_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MYSQLCONFIG8_0.fields_by_name['max_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MYSQLCONFIG8_0.fields_by_name['long_query_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_MYSQLCONFIG8_0.fields_by_name['general_log'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_MYSQLCONFIG8_0.fields_by_name['audit_log'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_MYSQLCONFIG8_0.fields_by_name['sql_mode'].enum_type = _MYSQLCONFIG8_0_SQLMODE
_MYSQLCONFIG8_0.fields_by_name['max_allowed_packet'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MYSQLCONFIG8_0.fields_by_name['default_authentication_plugin'].enum_type = _MYSQLCONFIG8_0_AUTHPLUGIN
_MYSQLCONFIG8_0.fields_by_name['innodb_flush_log_at_trx_commit'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MYSQLCONFIG8_0.fields_by_name['innodb_lock_wait_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MYSQLCONFIG8_0.fields_by_name['transaction_isolation'].enum_type = _MYSQLCONFIG8_0_TRANSACTIONISOLATION
_MYSQLCONFIG8_0.fields_by_name['innodb_print_all_deadlocks'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_MYSQLCONFIG8_0.fields_by_name['net_read_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MYSQLCONFIG8_0.fields_by_name['net_write_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MYSQLCONFIG8_0.fields_by_name['group_concat_max_len'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MYSQLCONFIG8_0.fields_by_name['tmp_table_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MYSQLCONFIG8_0.fields_by_name['max_heap_table_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MYSQLCONFIG8_0_SQLMODE.containing_type = _MYSQLCONFIG8_0
_MYSQLCONFIG8_0_AUTHPLUGIN.containing_type = _MYSQLCONFIG8_0
_MYSQLCONFIG8_0_TRANSACTIONISOLATION.containing_type = _MYSQLCONFIG8_0
_MYSQLCONFIGSET8_0.fields_by_name['effective_config'].message_type = _MYSQLCONFIG8_0
_MYSQLCONFIGSET8_0.fields_by_name['user_config'].message_type = _MYSQLCONFIG8_0
_MYSQLCONFIGSET8_0.fields_by_name['default_config'].message_type = _MYSQLCONFIG8_0
DESCRIPTOR.message_types_by_name['MysqlConfig8_0'] = _MYSQLCONFIG8_0
DESCRIPTOR.message_types_by_name['MysqlConfigSet8_0'] = _MYSQLCONFIGSET8_0
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MysqlConfig8_0 = _reflection.GeneratedProtocolMessageType('MysqlConfig8_0', (_message.Message,), {
  'DESCRIPTOR' : _MYSQLCONFIG8_0,
  '__module__' : 'yandex.cloud.mdb.mysql.v1.config.mysql8_0_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0)
  })
_sym_db.RegisterMessage(MysqlConfig8_0)

MysqlConfigSet8_0 = _reflection.GeneratedProtocolMessageType('MysqlConfigSet8_0', (_message.Message,), {
  'DESCRIPTOR' : _MYSQLCONFIGSET8_0,
  '__module__' : 'yandex.cloud.mdb.mysql.v1.config.mysql8_0_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mysql.v1.config.MysqlConfigSet8_0)
  })
_sym_db.RegisterMessage(MysqlConfigSet8_0)


DESCRIPTOR._options = None
_MYSQLCONFIG8_0.fields_by_name['innodb_buffer_pool_size']._options = None
_MYSQLCONFIG8_0.fields_by_name['max_connections']._options = None
_MYSQLCONFIG8_0.fields_by_name['max_allowed_packet']._options = None
_MYSQLCONFIG8_0.fields_by_name['innodb_flush_log_at_trx_commit']._options = None
_MYSQLCONFIG8_0.fields_by_name['innodb_lock_wait_timeout']._options = None
_MYSQLCONFIG8_0.fields_by_name['net_read_timeout']._options = None
_MYSQLCONFIG8_0.fields_by_name['net_write_timeout']._options = None
_MYSQLCONFIG8_0.fields_by_name['group_concat_max_len']._options = None
_MYSQLCONFIG8_0.fields_by_name['tmp_table_size']._options = None
_MYSQLCONFIG8_0.fields_by_name['max_heap_table_size']._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.mdb.mysql.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__pb2
from yandex.cloud.mdb.mysql.v1 import user_service_pb2 as yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class UserServiceStub(object):
  """A set of methods for managing MySQL users.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.UserService/Get',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2.GetUserRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__pb2.User.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.UserService/List',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2.ListUsersRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2.ListUsersResponse.FromString,
        )
    self.Create = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.UserService/Create',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2.CreateUserRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.UserService/Update',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2.UpdateUserRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.UserService/Delete',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2.DeleteUserRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.GrantPermission = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.UserService/GrantPermission',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2.GrantUserPermissionRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.RevokePermission = channel.unary_unary(
        '/yandex.cloud.mdb.mysql.v1.UserService/RevokePermission',
        request_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2.RevokeUserPermissionRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )


class UserServiceServicer(object):
  """A set of methods for managing MySQL users.
  """

  def Get(self, request, context):
    """Returns the specified MySQL user.

    To get the list of available MySQL users, make a [List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """Retrieves a list of MySQL users in the specified cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    """Creates a MySQL user in the specified cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Modifies the specified MySQL user.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Deletes the specified MySQL user.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GrantPermission(self, request, context):
    """Grants a permission to the specified MySQL user.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RevokePermission(self, request, context):
    """Revokes a permission from the specified MySQL user.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_UserServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2.GetUserRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__pb2.User.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2.ListUsersRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2.ListUsersResponse.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2.CreateUserRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2.UpdateUserRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2.DeleteUserRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'GrantPermission': grpc.unary_unary_rpc_method_handler(
          servicer.GrantPermission,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2.GrantUserPermissionRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'RevokePermission': grpc.unary_unary_rpc_method_handler(
          servicer.RevokePermission,
          request_deserializer=yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_user__service__pb2.RevokeUserPermissionRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.mdb.mysql.v1.UserService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.iot.devices.v1 import device_pb2 as yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__pb2
from yandex.cloud.iot.devices.v1 import device_service_pb2 as yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class DeviceServiceStub(object):
  """A set of methods for managing devices.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.iot.devices.v1.DeviceService/Get',
        request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.GetDeviceRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__pb2.Device.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.iot.devices.v1.DeviceService/List',
        request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicesRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicesResponse.FromString,
        )
    self.Create = channel.unary_unary(
        '/yandex.cloud.iot.devices.v1.DeviceService/Create',
        request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.CreateDeviceRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.iot.devices.v1.DeviceService/Update',
        request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.UpdateDeviceRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.iot.devices.v1.DeviceService/Delete',
        request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.DeleteDeviceRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListCertificates = channel.unary_unary(
        '/yandex.cloud.iot.devices.v1.DeviceService/ListCertificates',
        request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceCertificatesRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceCertificatesResponse.FromString,
        )
    self.AddCertificate = channel.unary_unary(
        '/yandex.cloud.iot.devices.v1.DeviceService/AddCertificate',
        request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.AddDeviceCertificateRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.DeleteCertificate = channel.unary_unary(
        '/yandex.cloud.iot.devices.v1.DeviceService/DeleteCertificate',
        request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.DeleteDeviceCertificateRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListPasswords = channel.unary_unary(
        '/yandex.cloud.iot.devices.v1.DeviceService/ListPasswords',
        request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicePasswordsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicePasswordsResponse.FromString,
        )
    self.AddPassword = channel.unary_unary(
        '/yandex.cloud.iot.devices.v1.DeviceService/AddPassword',
        request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.AddDevicePasswordRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.DeletePassword = channel.unary_unary(
        '/yandex.cloud.iot.devices.v1.DeviceService/DeletePassword',
        request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.DeleteDevicePasswordRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListOperations = channel.unary_unary(
        '/yandex.cloud.iot.devices.v1.DeviceService/ListOperations',
        request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceOperationsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceOperationsResponse.FromString,
        )


class DeviceServiceServicer(object):
  """A set of methods for managing devices.
  """

  def Get(self, request, context):
    """Returns the specified device.

    To get the list of available devices, make a [List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """Retrieves the list of devices in the specified registry.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    """Creates a device in the specified registry.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Updates the specified device.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Deletes the specified device.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListCertificates(self, request, context):
    """Retrieves the list of device certificates for the specified device.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddCertificate(self, request, context):
    """Adds a certificate.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteCertificate(self, request, context):
    """Deletes the specified device certificate.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListPasswords(self, request, context):
    """Retrieves the list of passwords for the specified device.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddPassword(self, request, context):
    """Adds password for the specified device.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeletePassword(self, request, context):
    """Deletes the specified password.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListOperations(self, request, context):
    """Lists operations for the specified device.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DeviceServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.GetDeviceRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__pb2.Device.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicesRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicesResponse.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.CreateDeviceRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.UpdateDeviceRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.DeleteDeviceRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListCertificates': grpc.unary_unary_rpc_method_handler(
          servicer.ListCertificates,
          request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceCertificatesRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceCertificatesResponse.SerializeToString,
      ),
      'AddCertificate': grpc.unary_unary_rpc_method_handler(
          servicer.AddCertificate,
          request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.AddDeviceCertificateRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'DeleteCertificate': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteCertificate,
          request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.DeleteDeviceCertificateRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListPasswords': grpc.unary_unary_rpc_method_handler(
          servicer.ListPasswords,
          request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicePasswordsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicePasswordsResponse.SerializeToString,
      ),
      'AddPassword': grpc.unary_unary_rpc_method_handler(
          servicer.AddPassword,
          request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.AddDevicePasswordRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'DeletePassword': grpc.unary_unary_rpc_method_handler(
          servicer.DeletePassword,
          request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.DeleteDevicePasswordRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListOperations': grpc.unary_unary_rpc_method_handler(
          servicer.ListOperations,
          request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceOperationsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceOperationsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.iot.devices.v1.DeviceService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.containerregistry.v1 import image_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__pb2
from yandex.cloud.containerregistry.v1 import image_service_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class ImageServiceStub(object):
  """A set of methods for managing Image resources.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.List = channel.unary_unary(
        '/yandex.cloud.containerregistry.v1.ImageService/List',
        request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__service__pb2.ListImagesRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__service__pb2.ListImagesResponse.FromString,
        )
    self.Get = channel.unary_unary(
        '/yandex.cloud.containerregistry.v1.ImageService/Get',
        request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__service__pb2.GetImageRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__pb2.Image.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.containerregistry.v1.ImageService/Delete',
        request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__service__pb2.DeleteImageRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )


class ImageServiceServicer(object):
  """A set of methods for managing Image resources.
  """

  def List(self, request, context):
    """Retrieves the list of Image resources in the specified registry or repository.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Get(self, request, context):
    """Returns the specified Image resource.

    To get the list of available Image resources, make a [List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Deletes the specified Docker image.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ImageServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__service__pb2.ListImagesRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__service__pb2.ListImagesResponse.SerializeToString,
      ),
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__service__pb2.GetImageRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__pb2.Image.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__service__pb2.DeleteImageRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.containerregistry.v1.ImageService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
